Name:           iwd
Version:        3.2
Release:        %mkrel 1
Summary:        Wireless daemon for Linux
License:        LGPLv2+
Group:          System/Networking
URL:            https://iwd.wiki.kernel.org/
Source0:        https://www.kernel.org/pub/linux/network/wireless/%{name}-%{version}.tar.xz
Patch1:         iwd-cflags.patch
BuildRequires:  asciidoc
BuildRequires:  gcc
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(ell) >= 0.69
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(readline)
BuildRequires:  python3-docutils

Requires:       dbus
Requires:       systemd
Recommends:     wireless-regdb


%description
The daemon and utilities for controlling and configuring the Wi-Fi network
hardware.


%prep
%autosetup -p1

# bundled ell
rm -rf ell

%build
autoreconf -fi
%configure			\
	--enable-external-ell	\
	--enable-ofono		\
	--enable-wired		\
	--enable-hwsim		\
	--enable-tools		\
	--with-systemd-unitdir=%{_unitdir} \
	--with-systemd-networkdir=%{_systemd_util_dir}/network \
	--with-systemd-modloaddir=%{_modulesloaddir}

%make_build


%install
%make_install

# Create directories
mkdir -p %{buildroot}%{_sysconfdir}/iwd
mkdir -p %{buildroot}%{_sharedstatedir}/{ead,iwd}

# Install main.conf
install -Dpm644 doc/main.conf %{buildroot}%{_sysconfdir}/iwd/main.conf

# Don't let iwd adjust interface naming. It would break user configurations.
rm %{buildroot}/usr/lib/systemd/network/80-iwd.link


%files
%license COPYING
%doc AUTHORS ChangeLog
%dir %{_sysconfdir}/iwd/
%config(noreplace) %{_sysconfdir}/iwd/main.conf
%{_bindir}/iwctl
%{_bindir}/iwmon
%{_bindir}/hwsim
%{_libexecdir}/iwd
%{_libexecdir}/ead
%{_modulesloaddir}/pkcs8.conf
%{_unitdir}/ead.service
%{_unitdir}/iwd.service
%{_datadir}/dbus-1/system-services/net.connman.iwd.service
%{_datadir}/dbus-1/system-services/net.connman.ead.service
%{_datadir}/dbus-1/system.d/iwd-dbus.conf
%{_datadir}/dbus-1/system.d/ead-dbus.conf
%{_datadir}/dbus-1/system.d/hwsim-dbus.conf
%{_mandir}/man*/*
%dir %{_sharedstatedir}/iwd/
%dir %{_sharedstatedir}/ead/


%changelog
* Fri Nov 29 2024 daviddavid <daviddavid> 3.2-1.mga10
+ Revision: 2119721
- new version: 3.2

* Fri Nov 08 2024 wally <wally> 3.1-1.mga10
+ Revision: 2113031
- new version 3.1

* Fri Oct 25 2024 wally <wally> 3.0-1.mga10
+ Revision: 2111202
- new version 3.0

* Thu Sep 12 2024 ns80 <ns80> 2.22-1.mga10
+ Revision: 2095303
- new version 2.22 for CVE-2023-52424 (mga#33559)

* Sat Aug 31 2024 wally <wally> 2.20-1.mga10
+ Revision: 2092390
- new version 2.20

* Thu Jul 11 2024 wally <wally> 2.19-1.mga10
+ Revision: 2080706
- new version 2.19

* Wed Jun 05 2024 daviddavid <daviddavid> 2.18-1.mga10
+ Revision: 2070095
- new version: 2.18

* Sun Apr 21 2024 wally <wally> 2.17-1.mga10
+ Revision: 2060392
- new version 2.17
- add patch to not override our CFLAGS

* Sat Mar 09 2024 wally <wally> 2.16-1.mga10
+ Revision: 2048875
- new version 2.16

* Sat Feb 10 2024 wally <wally> 2.14-1.mga10
+ Revision: 2040160
- new version 2.14

* Sun Jan 28 2024 wally <wally> 2.13-1.mga10
+ Revision: 2035584
- new version 2.13
- enable position independent executables flag -fPIE

* Thu Nov 23 2023 wally <wally> 2.9-1.mga10
+ Revision: 2009413
- new version 2.9

* Sun Aug 27 2023 wally <wally> 2.8-1.mga10
+ Revision: 1980291
- new version 2.8
- Import based on Fedora


* Thu Jul 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Fri Jun 23 2023 Peter Robinson <pbrobinson@fedoraproject.org> - 2.6-1
- Update to 2.6

* Sun May 28 2023 Peter Robinson <pbrobinson@fedoraproject.org> - 2.5-1
- Update to 2.5

* Wed Mar 29 2023 Peter Robinson <pbrobinson@fedoraproject.org> - 2.4-1
- Update to 2.4

* Sat Feb 04 2023 Peter Robinson <pbrobinson@fedoraproject.org> - 2.3-1
- Update to 2.3

* Tue Jan 24 2023 Peter Robinson <pbrobinson@fedoraproject.org> - 2.2-3
- Update to 2.2

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sat Dec 31 2022 Peter Robinson <pbrobinson@fedoraproject.org> - 2.1-1
- Update to 2.1

* Sun Nov 20 2022 Neal Gompa <ngompa@fedoraproject.org> - 2.0-2
- Properly remove files intended to be excluded from the package

* Sat Nov 19 2022 Peter Robinson <pbrobinson@fedoraproject.org> - 2.0-1
- Update to 2.0

* Thu Jul 28 2022 Peter Robinson <pbrobinson@fedoraproject.org> - 1.29-1
- Update to 1.29

* Thu Jul 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.27-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Sun May 15 2022 Peter Robinson <pbrobinson@fedoraproject.org> - 1.27-1
- Update to 1.27

* Sat Mar 26 2022 Peter Robinson <pbrobinson@fedoraproject.org> - 1.26-1
- Update to 1.26

* Sat Feb 12 2022 Peter Robinson <pbrobinson@fedoraproject.org> - 1.24-1
- Update to 1.24

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.21-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Jan 05 2022 Peter Robinson <pbrobinson@fedoraproject.org> - 1.21-1
- Update to 1.21

* Sat Dec 11 2021 Peter Robinson <pbrobinson@fedoraproject.org> - 1.20-1
- Update to 1.20

* Sun Nov 07 2021 Peter Robinson <pbrobinson@fedoraproject.org> - 1.19-1
- Update to 1.19

* Sun Sep 19 2021 Peter Robinson <pbrobinson@fedoraproject.org> - 1.18-1
- Update to 1.18

* Sun Aug 22 2021 Peter Robinson <pbrobinson@fedoraproject.org> - 1.17-1
- Update to 1.17

* Sat Aug 07 2021 Peter Robinson <pbrobinson@fedoraproject.org> - 1.16-1
- Update to 1.16

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.15-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Jun 15 2021 Peter Robinson <pbrobinson@fedoraproject.org> - 1.15-1
- Update to 1.15

* Sat May 15 2021 Peter Robinson <pbrobinson@fedoraproject.org> - 1.14-1
- Update to 1.14

* Tue Mar 30 2021 Peter Robinson <pbrobinson@fedoraproject.org> - 1.13-1
- Update to 1.13

* Thu Feb 18 2021 Peter Robinson <pbrobinson@fedoraproject.org> - 1.12-1
- Update to 1.12

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Mon Jan 11 2021 Peter Robinson <pbrobinson@fedoraproject.org> - 1.11-1
- Update to 1.11

* Tue Dec  1 2020 Peter Robinson <pbrobinson@fedoraproject.org> - 1.10-1
- Update to 1.10

* Sun Sep 06 2020 Peter Robinson <pbrobinson@fedoraproject.org> - 1.9-1
- Update to 1.9

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Jun 15 2020 Peter Robinson <pbrobinson@fedoraproject.org> - 1.8-1
- Update to 1.8 release

* Wed Mar 25 2020 Peter Robinson <pbrobinson@fedoraproject.org> - 1.6-1
- Update to 1.6 release

* Sun Feb  9 2020 Peter Robinson <pbrobinson@fedoraproject.org> 1.5-1
- Update to 1.5 release

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Fri Dec 20 2019 Peter Robinson <pbrobinson@fedoraproject.org> 1.4-1
- Update to 1.4 release

* Sat Dec 14 2019 Peter Robinson <pbrobinson@fedoraproject.org> 1.3-1
- Update to 1.3 release

* Fri Nov 15 2019 Peter Robinson <pbrobinson@fedoraproject.org> 1.1-1
- Update to 1.1 release

* Wed Oct 30 2019 Lubomir Rintel <lkundrak@v3.sk> - 1.0-1
- Update to 1.0 release

* Fri Oct 25 2019 Peter Robinson <pbrobinson@gmail.com> - 0.23-1
- Update to 0.23 release

* Fri Oct 11 2019 Peter Robinson <pbrobinson@fedoraproject.org> 0.22-1
- Update to 0.22 release

* Fri Sep 20 2019 Peter Robinson <pbrobinson@fedoraproject.org> 0.21-1
- Update to 0.21 release

* Fri Sep 06 2019 Lubomir Rintel <lkundrak@v3.sk> - 0.20-2
- Create /var/lib/iwd and /var/lib/ead
- Bump the ell requirement

* Thu Aug 29 2019 Peter Robinson <pbrobinson@fedoraproject.org> 0.20-1
- Update to 0.20 release

* Mon Aug 05 2019 Lubomir Rintel <lkundrak@v3.sk> - 0.19-1
- Update to 0.19 release

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.18-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sun May 12 2019 Peter Robinson <pbrobinson@fedoraproject.org> 0.18-1
- Update to 0.18 release

* Mon Apr 15 2019 Peter Robinson <pbrobinson@fedoraproject.org> 0.17-1
- Update to 0.17 release

* Thu Apr  4 2019 Peter Robinson <pbrobinson@fedoraproject.org> 0.16-1
- Update to 0.16 release

* Sun Feb 17 2019 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.14-3
- Rebuild for readline 8.0

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.14-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Thu Jan 17 2019 Peter Robinson <pbrobinson@fedoraproject.org> 0.14-1
- Update to 0.14 release

* Wed Dec 12 2018 Peter Robinson <pbrobinson@fedoraproject.org> 0.13-1
- Update to 0.13 release

* Fri Nov 16 2018 Peter Robinson <pbrobinson@fedoraproject.org> 0.12-1
- Update to 0.12 release

* Sat Nov 10 2018 Peter Robinson <pbrobinson@fedoraproject.org> 0.11-1
- Update to 0.11 release

* Mon Sep 24 2018 Lubomir Rintel <lkundrak@v3.sk> - 0.8-1
- Update to 0.8 release

* Sat Aug 11 2018 Lubomir Rintel <lkundrak@v3.sk> - 0.6-1
- Update to 0.6 release

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Jun 25 2018 Lubomir Rintel <lkundrak@v3.sk> - 0.3-1
- Update to 0.3 release

* Mon May 14 2018 Lubomir Rintel <lkundrak@v3.sk> - 0.2-1
- Update to 0.2 release

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.0-0.3.20171026git569be48
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sun Oct 29 2017 Lubomir Rintel <lkundrak@v3.sk> - 0.0-0.2.20171026git569be48
- Update to a later snapshot

* Sun Oct 22 2017 Lubomir Rintel <lkundrak@v3.sk> - 0.0-0.2.20171022git2c56501
- Added BR gcc
- Made build verbose
- Fixed license tag
- Addressed review issues (Robert-André Mauchin, #1505238):
- Dropped Group tag
- Added license and documentation texts

* Sun Oct 22 2017 Lubomir Rintel <lkundrak@v3.sk> - 0.0-0.1.20171022git2c56501
- Initial packaging
